==> obsinfo-0.104.1.post4.tar.gz: obsinfo-0.104.1.post4/setup.py <==
import setuptools

with open("README.rst", "r") as fh:
    long_description = fh.read()
    
version={}
with open("obsinfo/version.py") as fp:
    exec(fp.read(),version)

setuptools.setup(
    name="obsinfo",
    #version="0.104",
    version=version['__version__'],
    author="Wayne Crawford",
    author_email="crawford@ipgp.fr",
    description="Tools for documenting ocean bottom seismometer experiments and creating meta/data",
    long_description=long_description,
    long_description_content_type="text/x-rst; charset=UTF-8",
    url="https://github.com/pypa/obsinfo",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=[
          'obspy>=1.1',
          'pyyaml>=3.0',
          'jsonschema>=2.6',
          'jsonref>=0.2'
      ],
#     scripts=[
#         'scripts/obsinfo-print.py',
#         'scripts/obsinfo-makeSTATIONXML.py'
#     ],
    entry_points={
        'console_scripts': [
            'obsinfo-validate=obsinfo.misc.info_files:_validate_script',
            'obsinfo-print=obsinfo.misc.print:_print_script',
            'obsinfo-makeSTATIONXML=obsinfo.network.network:_make_stationXML_script'
        ]
    },
    python_requires='>=3',
    classifiers=(
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Physics"
    ),
    keywords='seismology OBS'
)

==> obsinfo-0.104.2.tar.gz: obsinfo-0.104.2/setup.py <==
import setuptools

with open("README.rst", "r") as fh:
    long_description = fh.read()
    
version={}
with open("obsinfo/version.py") as fp:
    exec(fp.read(),version)

setuptools.setup(
    name="obsinfo",
    #version="0.104",
    version=version['__version__'],
    author="Wayne Crawford",
    author_email="crawford@ipgp.fr",
    description="Tools for documenting ocean bottom seismometer experiments and creating meta/data",
    long_description=long_description,
    long_description_content_type="text/x-rst; charset=UTF-8",
    url="https://github.com/pypa/obsinfo",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=[
          'obspy>=1.1',
          'pyyaml>=3.0',
          'jsonschema>=2.6',
          'jsonref>=0.2'
      ],
#     scripts=[
#         'scripts/obsinfo-print.py',
#         'scripts/obsinfo-makeSTATIONXML.py'
#     ],
    entry_points={
        'console_scripts': [
            'obsinfo-validate=obsinfo.misc.info_files:_validate_script',
            'obsinfo-print=obsinfo.misc.print:_print_script',
            'obsinfo-makeSTATIONXML=obsinfo.network.network:_make_stationXML_script',
            'obsinfo-make_process_scripts_SDPCHAIN=obsinfo.addons.SDPCHAIN:_console_script',
            'obsinfo-make_process_scripts_LC2MS=obsinfo.addons.LCHEAPO:_console_script'
        ]
    },
    python_requires='>=3',
    classifiers=(
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Physics"
    ),
    keywords='seismology OBS'
)
